@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: cae_alsa.cpp,v 1.38 2007/12/26 17:44:03 grauf Exp $
+//      $Id: cae_alsa.cpp,v 1.41 2008/07/18 20:06:10 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -76,8 +76,9 @@ void AlsaCapture2Callback(struct alsa_format *alsa_format)
        (!alsa_format->exiting)) {
       snd_pcm_drop (alsa_format->pcm);
       snd_pcm_prepare(alsa_format->pcm);
-      LogLine(QString().sprintf("****** ALSA Capture Xrun - Card: %d ******",
-				alsa_format->card));
+      LogLine(RDConfig::LogNotice,QString().
+	      sprintf("****** ALSA Capture Xrun - Card: %d ******",
+		      alsa_format->card));
     }
     else {
       switch(alsa_format->format) {
@@ -296,7 +297,6 @@ void AlsaPlay2Callback(struct alsa_format *alsa_format)
 		      read(alsa_buffer,alsa_format->
 			   buffer_size/alsa_format->periods)/
 		      (2*sizeof(short));
-		    LogLine(QString().sprintf("N: %d",n));
 		    modulo=alsa_format->channels;
 		    for(unsigned i=0;i<(alsa_format->channels/2);i++) {
 		      if(alsa_output_volume[alsa_format->card][i][j]!=0.0) {
@@ -506,18 +506,21 @@ void AlsaPlay2Callback(struct alsa_format *alsa_format)
     int s=snd_pcm_writei(alsa_format->pcm,alsa_format->card_buffer,n);
     if(s!=n) {
       if(s<0) {
-	LogLine(QString().sprintf("*** alsa error %d: %s",-s,snd_strerror(s)));
+	LogLine(RDConfig::LogNotice,
+		QString().sprintf("*** alsa error %d: %s",-s,snd_strerror(s)));
       }
       else {
-	LogLine(QString().sprintf("period size mismatch - wrote %d\n",s));
+	LogLine(RDConfig::LogNotice,
+		QString().sprintf("period size mismatch - wrote %d\n",s));
       }
     }
     if((snd_pcm_state(alsa_format->pcm)!=SND_PCM_STATE_RUNNING)&&
        (!alsa_format->exiting)) {
       snd_pcm_drop (alsa_format->pcm);
       snd_pcm_prepare(alsa_format->pcm);
-      LogLine(QString().sprintf("****** ALSA Playout Xrun - Card: %d ******",
-				alsa_format->card));
+      LogLine(RDConfig::LogNotice,QString().
+	      sprintf("****** ALSA Playout Xrun - Card: %d ******",
+		      alsa_format->card));
     }
   }
 }
@@ -610,7 +613,7 @@ void MainObject::alsaFadeTimerData(int cardstream)
       alsa_fade_timer[card][stream]->stop();
     }
   }
-  LogLine(QString().sprintf("FadeLevel: %d",level));
+  LogLine(RDConfig::LogDebug,QString().sprintf("FadeLevel: %d",level));
   alsaSetOutputVolume(card,stream,alsa_fade_port[card][stream],level);
 #endif  // ALSA
 }
@@ -725,8 +728,9 @@ void MainObject::alsaInit(RDStation *station)
       if(cae_driver[i]==RDStation::Alsa) {
 	station->setCardDriver(i,RDStation::Alsa);
 	if(snd_ctl_open(&snd_ctl,dev,0)<0) {
-	  LogLine(QString().sprintf("no control device found for %s",
-				    (const char *)dev));
+	  LogLine(RDConfig::LogNotice,QString().
+		  sprintf("no control device found for %s",
+			  (const char *)dev));
 	  station->
 	    setCardName(i,
 			QString().sprintf("ALSA Device %s",(const char *)dev));
@@ -775,7 +779,7 @@ bool MainObject::alsaLoadPlayback(int card,QString wavename,int *stream)
 {
 #ifdef ALSA
   if(alsa_play_format[card].exiting || ((*stream=GetAlsaOutputStream(card))<0)) {
-    LogLine(QString().sprintf(
+    LogLine(RDConfig::LogErr,QString().sprintf(
             "Error: alsaLoadPlayback(%s) GetAlsaOutputStream():%d < 0",
             (const char *) wavename,
             *stream) );
@@ -783,7 +787,7 @@ bool MainObject::alsaLoadPlayback(int card,QString wavename,int *stream)
   }
   alsa_play_wave[card][*stream]=new RDWaveFile(wavename);
   if(!alsa_play_wave[card][*stream]->openWave()) {
-    LogLine(QString().sprintf(
+    LogLine(RDConfig::LogErr,QString().sprintf(
             "Error: alsaLoadPlayback(%s)   openWave() failed to open file",
             (const char *) wavename) );
     delete alsa_play_wave[card][*stream];
@@ -794,7 +798,7 @@ bool MainObject::alsaLoadPlayback(int card,QString wavename,int *stream)
   }
   if((alsa_play_wave[card][*stream]->getFormatTag()!=WAVE_FORMAT_PCM)||
      (alsa_play_wave[card][*stream]->getBitsPerSample()!=16)) {
-    LogLine(QString().sprintf(
+    LogLine(RDConfig::LogErr,QString().sprintf(
             "Error: alsaLoadPlayback(%s)   getFormatTag()%d || getBistsPerSample()%d failed",
             (const char *) wavename,
             alsa_play_wave[card][*stream]->getFormatTag(),
@@ -870,7 +874,7 @@ bool MainObject::alsaPlay(int card,int stream,int length,int speed,bool pitch,
 {
 #ifdef ALSA
   if((alsa_play_ring[card][stream]==NULL)||
-     alsa_playing[card][stream]||(speed!=1000)) {
+     alsa_playing[card][stream]||(speed!=RD_TIMESCALE_DIVISOR)) {
     return false;
   }
   alsa_playing[card][stream]=true;
@@ -1178,9 +1182,8 @@ void MainObject::alsaGetOutputPosition(int card,unsigned *pos)
 #ifdef ALSA
   for(int i=0;i<RD_MAX_STREAMS;i++) {
     if (!alsa_play_format[card].exiting){
-      pos[i]=(((unsigned long long)(alsa_offset[card][i]+
-				    alsa_output_pos[card][i]))* 
-	      1000)/alsa_play_format[card].sample_rate;
+      pos[i]=((unsigned long long)(alsa_offset[card][i]+
+				    alsa_output_pos[card][i]));
     } else {
       pos = 0;
     }
@@ -1224,16 +1227,17 @@ bool MainObject::AlsaStartCaptureDevice(QString &dev,int card,snd_pcm_t *pcm)
   snd_pcm_hw_params_alloca(&hwparams);
   snd_pcm_hw_params_any(pcm,hwparams);
 
-  LogLine(QString().sprintf("Starting ALSA Capture Device %s:",
-			    (const char *)dev));
+  LogLine(RDConfig::LogInfo,QString().
+	  sprintf("Starting ALSA Capture Device %s:",
+		  (const char *)dev));
 
   //
   // Access Type
   //
   if(snd_pcm_hw_params_test_access(pcm,hwparams,
 				   SND_PCM_ACCESS_RW_INTERLEAVED)<0) {
-    LogLine("  Interleaved access not supported,");
-    LogLine("  aborting initialization of device.");
+    LogLine(RDConfig::LogErr,"  Interleaved access not supported,");
+    LogLine(RDConfig::LogErr,"  aborting initialization of device.");
     return false;
   }
   snd_pcm_hw_params_set_access(pcm,hwparams,SND_PCM_ACCESS_RW_INTERLEAVED);
@@ -1243,16 +1247,18 @@ bool MainObject::AlsaStartCaptureDevice(QString &dev,int card,snd_pcm_t *pcm)
   //
   if(snd_pcm_hw_params_test_format(pcm,hwparams,SND_PCM_FORMAT_S16_LE)==0) {
     alsa_capture_format[card].format=SND_PCM_FORMAT_S16_LE;
-    LogLine("  Format = 16 bit little-endian");
+    LogLine(RDConfig::LogDebug,"  Format = 16 bit little-endian");
   }
   else {
     if(snd_pcm_hw_params_test_format(pcm,hwparams,SND_PCM_FORMAT_S32_LE)==0) {
       alsa_capture_format[card].format=SND_PCM_FORMAT_S32_LE;
-      LogLine("  Format = 32 bit little-endian");
+      LogLine(RDConfig::LogDebug,"  Format = 32 bit little-endian");
     }
     else {
-      LogLine("  Neither 16 nor 32 bit little-endian formats available,");
-      LogLine("  aborting initialization of device.");
+      LogLine(RDConfig::LogErr,
+	      "  Neither 16 nor 32 bit little-endian formats available,");
+      LogLine(RDConfig::LogErr,
+	      "  aborting initialization of device.");
       return false;
     }
   }
@@ -1273,7 +1279,7 @@ bool MainObject::AlsaStartCaptureDevice(QString &dev,int card,snd_pcm_t *pcm)
     sr=rd_config->sampleRate();
   }
   alsa_capture_format[card].sample_rate=sr;
-  LogLine(QString().sprintf("  SampleRate = %u",sr));
+  LogLine(RDConfig::LogNotice,QString().sprintf("  SampleRate = %u",sr));
 
   //
   // Channels
@@ -1282,8 +1288,9 @@ bool MainObject::AlsaStartCaptureDevice(QString &dev,int card,snd_pcm_t *pcm)
   snd_pcm_hw_params_set_channels_near(pcm,hwparams,
 				      &alsa_capture_format[card].channels);
   alsa_play_format[card].capture_channels=alsa_capture_format[card].channels;
-  LogLine(QString().sprintf("  Aggregate Channels = %u",
-			    alsa_capture_format[card].channels));
+  LogLine(RDConfig::LogDebug,QString().
+	  sprintf("  Aggregate Channels = %u",
+		  alsa_capture_format[card].channels));
 
   //
   // Buffer Size
@@ -1291,26 +1298,25 @@ bool MainObject::AlsaStartCaptureDevice(QString &dev,int card,snd_pcm_t *pcm)
   alsa_capture_format[card].periods=rd_config->alsaPeriodQuantity();
   snd_pcm_hw_params_set_periods_near(pcm,hwparams,
 				     &alsa_capture_format[card].periods,&dir);
-  LogLine(QString().sprintf("  Periods = %u",
-			    alsa_capture_format[card].periods));
+  LogLine(RDConfig::LogDebug,QString().sprintf("  Periods = %u",
+		  alsa_capture_format[card].periods));
   alsa_capture_format[card].buffer_size=
     alsa_capture_format[card].periods*rd_config->alsaPeriodSize();
   snd_pcm_hw_params_set_buffer_size_near(pcm,hwparams,
 	       			 &alsa_capture_format[card].buffer_size);
-  LogLine(QString().
-    sprintf("  BufferSize = %u frames",
+  LogLine(RDConfig::LogDebug,QString().sprintf("  BufferSize = %u frames",
 	    (unsigned)alsa_capture_format[card].buffer_size));
 
   //
   // Fire It Up
   //
   if((err=snd_pcm_hw_params(pcm,hwparams))<0) {
-    LogLine(QString().sprintf("  Device Error: %s,",
+    LogLine(RDConfig::LogErr,QString().sprintf("  Device Error: %s,",
 			      (const char *)snd_strerror(err)));
-    LogLine("  aborting initialization of device.");
+    LogLine(RDConfig::LogErr,"  aborting initialization of device.");
     return false;
   }
-  LogLine("  Device started successfully");
+  LogLine(RDConfig::LogNotice,"  Device started successfully");
   switch(alsa_capture_format[card].format) {
       case SND_PCM_FORMAT_S16_LE:
 	alsa_capture_format[card].card_buffer_size=
@@ -1340,7 +1346,7 @@ bool MainObject::AlsaStartCaptureDevice(QString &dev,int card,snd_pcm_t *pcm)
   snd_pcm_sw_params_current(pcm,swparams);
   snd_pcm_sw_params_set_avail_min(pcm,swparams,rd_config->alsaPeriodSize());
   if((err=snd_pcm_sw_params(pcm,swparams))<0) {
-    LogLine(QString().sprintf("ALSA Device %s: %s",
+    LogLine(RDConfig::LogErr,QString().sprintf("ALSA Device %s: %s",
 			      (const char *)dev,
 			      (const char *)snd_strerror(err)));
     return false;
@@ -1376,16 +1382,16 @@ bool MainObject::AlsaStartPlayDevice(QString &dev,int card,snd_pcm_t *pcm)
   snd_pcm_hw_params_alloca(&hwparams);
   snd_pcm_hw_params_any(pcm,hwparams);
 
-  LogLine(QString().sprintf("Starting ALSA Play Device %s:",
-			    (const char *)dev));
+  LogLine(RDConfig::LogNotice,QString().sprintf("Starting ALSA Play Device %s:",
+						(const char *)dev));
 
   //
   // Access Type
   //
   if(snd_pcm_hw_params_test_access(pcm,hwparams,
 				   SND_PCM_ACCESS_RW_INTERLEAVED)<0) {
-    LogLine("  Interleaved access not supported,");
-    LogLine("  aborting initialization of device.");
+    LogLine(RDConfig::LogErr,"  Interleaved access not supported,");
+    LogLine(RDConfig::LogErr,"  aborting initialization of device.");
     return false;
   }
   snd_pcm_hw_params_set_access(pcm,hwparams,SND_PCM_ACCESS_RW_INTERLEAVED);
@@ -1395,16 +1401,17 @@ bool MainObject::AlsaStartPlayDevice(QString &dev,int card,snd_pcm_t *pcm)
   //
   if(snd_pcm_hw_params_test_format(pcm,hwparams,SND_PCM_FORMAT_S16_LE)==0) {
     alsa_play_format[card].format=SND_PCM_FORMAT_S16_LE;
-    LogLine("  Format = 16 bit little-endian");
+    LogLine(RDConfig::LogDebug,"  Format = 16 bit little-endian");
   }
   else {
     if(snd_pcm_hw_params_test_format(pcm,hwparams,SND_PCM_FORMAT_S32_LE)==0) {
       alsa_play_format[card].format=SND_PCM_FORMAT_S32_LE;
-      LogLine("  Format = 32 bit little-endian");
+      LogLine(RDConfig::LogDebug,"  Format = 32 bit little-endian");
     }
     else {
-      LogLine("  Neither 16 nor 32 bit little-endian formats available,");
-      LogLine("  aborting initialization of device.");
+      LogLine(RDConfig::LogErr,
+	      "  Neither 16 nor 32 bit little-endian formats available,");
+      LogLine(RDConfig::LogErr,"  aborting initialization of device.");
       return false;
     }
   }
@@ -1420,7 +1427,7 @@ bool MainObject::AlsaStartPlayDevice(QString &dev,int card,snd_pcm_t *pcm)
     sr=rd_config->sampleRate();
   }
   alsa_play_format[card].sample_rate=sr;
-  LogLine(QString().sprintf("  SampleRate = %u",sr));
+  LogLine(RDConfig::LogDebug,QString().sprintf("  SampleRate = %u",sr));
 
   //
   // Channels
@@ -1428,7 +1435,7 @@ bool MainObject::AlsaStartPlayDevice(QString &dev,int card,snd_pcm_t *pcm)
   alsa_play_format[card].channels=rd_config->channels()*RD_MAX_PORTS;
   snd_pcm_hw_params_set_channels_near(pcm,hwparams,
 				      &alsa_play_format[card].channels);
-  LogLine(QString().sprintf("  Aggregate Channels = %u",
+  LogLine(RDConfig::LogDebug,QString().sprintf("  Aggregate Channels = %u",
 			    alsa_play_format[card].channels));
 
   //
@@ -1437,12 +1444,13 @@ bool MainObject::AlsaStartPlayDevice(QString &dev,int card,snd_pcm_t *pcm)
   alsa_play_format[card].periods=rd_config->alsaPeriodQuantity();
   snd_pcm_hw_params_set_periods_near(pcm,hwparams,
 				     &alsa_play_format[card].periods,&dir);
-  LogLine(QString().sprintf("  Periods = %u",alsa_play_format[card].periods));
+  LogLine(RDConfig::LogDebug,QString().sprintf("  Periods = %u",
+					       alsa_play_format[card].periods));
   alsa_play_format[card].buffer_size=
     alsa_play_format[card].periods*rd_config->alsaPeriodSize();
   snd_pcm_hw_params_set_buffer_size_near(pcm,hwparams,
 					 &alsa_play_format[card].buffer_size);
-  LogLine(QString().
+  LogLine(RDConfig::LogDebug,QString().
        sprintf("  BufferSize = %u frames",
 	       (unsigned)alsa_play_format[card].buffer_size));
 
@@ -1450,12 +1458,12 @@ bool MainObject::AlsaStartPlayDevice(QString &dev,int card,snd_pcm_t *pcm)
   // Fire It Up
   //
   if((err=snd_pcm_hw_params(pcm,hwparams))<0) {
-    LogLine(QString().sprintf("  Device Error: %s,",
+    LogLine(RDConfig::LogErr,QString().sprintf("  Device Error: %s,",
 			      (const char *)snd_strerror(err)));
-    LogLine("  aborting initialization of device.");
+    LogLine(RDConfig::LogErr,"  aborting initialization of device.");
     return false;
   }
-  LogLine("  Device started successfully");
+  LogLine(RDConfig::LogNotice,"  Device started successfully");
   switch(alsa_play_format[card].format) {
       case SND_PCM_FORMAT_S16_LE:
 	alsa_play_format[card].card_buffer_size=
@@ -1484,9 +1492,9 @@ bool MainObject::AlsaStartPlayDevice(QString &dev,int card,snd_pcm_t *pcm)
   snd_pcm_sw_params_current(pcm,swparams);
   snd_pcm_sw_params_set_avail_min(pcm,swparams,rd_config->alsaPeriodSize());
   if((err=snd_pcm_sw_params(pcm,swparams))<0) {
-    LogLine(QString().sprintf("ALSA Device %s: %s",
-			      (const char *)dev,
-			      (const char *)snd_strerror(err)));
+    LogLine(RDConfig::LogErr,QString().sprintf("ALSA Device %s: %s",
+					       (const char *)dev,
+					    (const char *)snd_strerror(err)));
     return false;
   }
 
