@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdadd_log.cpp,v 1.9 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdadd_log.cpp,v 1.11 2008/04/01 20:51:39 grauf Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -34,15 +34,17 @@
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
 #include <qsqldatabase.h>
-
+#include <rddb.h>
 #include <rdtextvalidator.h>
 #include <rdadd_log.h>
 
 
 RDAddLog::RDAddLog(QString *logname,QString *svcname,RDStation *station,
-		   QString caption,QWidget *parent,const char *name)
+		   QString caption,QWidget *parent,const char *name, 
+                   RDUser *rduser)
   : QDialog(parent,name,true)
 {
+  QStringList services_list;
   log_name=logname;
   log_svc=svcname;
   log_station=station;
@@ -96,7 +98,7 @@ RDAddLog::RDAddLog(QString *logname,QString *svcname,RDStation *station,
   validator->addBannedChar('/');
 
   //
-  // Group Name
+  // Log Name
   //
   add_name_edit=new QLineEdit(this,"add_name_edit");
   add_name_edit->setGeometry(115,11,100,19);
@@ -108,6 +110,9 @@ RDAddLog::RDAddLog(QString *logname,QString *svcname,RDStation *station,
   label->setFont(button_font);
   label->setAlignment(AlignRight|ShowPrefix);
 
+  //
+  // Service selector
+  //
   add_service_box=new QComboBox(this,"add_sevice_box");
   add_service_box->setGeometry(115,33,100,19);
   label=new QLabel(add_name_edit,tr("&Service:"),this,"add_service_label");
@@ -137,23 +142,33 @@ RDAddLog::RDAddLog(QString *logname,QString *svcname,RDStation *station,
   //
   // Populate Data
   //
-  QString sql;
-  if(station==NULL) {
-    sql="select NAME from SERVICES order by NAME";
+  if (rduser != 0) { // RDStation::UserSec
+    services_list = rduser->services();
+  } else { // RDStation::HostSec
+    QString sql;
+    if(station==NULL) {
+      sql="select NAME from SERVICES order by NAME";
+    }
+    else {
+      sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS \
+                             where STATION_NAME=\"%s\" order by SERVICE_NAME",
+  			    (const char *)station->name());
+    }
+    RDSqlQuery *q=new RDSqlQuery(sql);
+    while(q->next()) {
+      services_list.append( q->value(0).toString() );
+    }
+    delete q;
   }
-  else {
-    sql=QString().sprintf("select SERVICE_NAME from SERVICE_PERMS \
-                           where STATION_NAME=\"%s\" order by SERVICE_NAME",
-			  (const char *)station->name());
-  }
-  QSqlQuery *q=new QSqlQuery(sql);
-  while(q->next()) {
-    add_service_box->insertItem(q->value(0).toString());
-    if(*svcname==q->value(0).toString()) {
+
+  for ( QStringList::Iterator it = services_list.begin(); 
+        it != services_list.end();
+        ++it ) {
+    add_service_box->insertItem(*it);
+    if(*svcname==*it) {
       add_service_box->setCurrentItem(add_service_box->count()-1);
     }
   }
-  delete q;
 }
 
 
@@ -185,6 +200,11 @@ void RDAddLog::okData()
     QMessageBox::warning(this,tr("RDLogEdit"),tr("The name is invalid!"));
     return;
   }
+  if(add_service_box->currentText().isEmpty()){
+    QMessageBox::warning(this,tr("RDLogEdit"),tr("The service is invalid!"));
+    return;
+  }
+
   *log_name=add_name_edit->text();
   *log_svc=add_service_box->currentText();
   done(0);
