@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdairplay_conf.h,v 1.29 2007/07/10 16:02:21 fredg Exp $
+//      $Id: rdairplay_conf.h,v 1.31.2.1 2008/12/02 20:35:21 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -101,6 +101,8 @@ class RDAirPlayConf
   void setExitCode(RDAirPlayConf::ExitCode code) const;
   bool exitPasswordValid(const QString &passwd) const;
   void setExitPassword(const QString &passwd) const;
+  QString skinPath() const;
+  void setSkinPath(const QString &path) const;
   RDAirPlayConf::StartMode startMode(int lognum) const;
   void setStartMode(int lognum,RDAirPlayConf::StartMode mode) const;
   bool autoRestart(int lognum) const;
@@ -115,11 +117,15 @@ class RDAirPlayConf
   void setLogId(int lognum,int id) const;
   int logCurrentLine(int lognum) const;
   void setLogCurrentLine(int lognum,int line) const;
+  unsigned logNowCart(int lognum) const;
+  void setLogNowCart(int lognum,unsigned cartnum) const;
+  unsigned logNextCart(int lognum) const;
+  void setLogNextCart(int lognum,unsigned cartnum) const;
 
  private:
-  void SetRow(QString param,int value) const;
-  void SetRow(QString param,QString value) const;
-  void SetRow(QString param,bool value) const;
+  void SetRow(const QString &param,int value) const;
+  void SetRow(const QString &param,unsigned value) const;
+  void SetRow(const QString &param,const QString &value) const;
   QString air_station;
   unsigned air_instance;
   unsigned air_id;
