@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdmacro.h,v 1.28 2007/06/12 23:02:36 fredg Exp $
+//      $Id: rdmacro.h,v 1.30.2.2 2008/12/03 20:24:41 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -39,12 +39,13 @@ class RDMacro
  public:
   enum Command {BO=0x424F,CC=0x4343,CL=0x434C,DB=0x4442,EX=0x4558,FS=0x4653,
 		GE=0x4745,GI=0x4749,GO=0x474F,LB=0x4C42,LC=0x4C43,LL=0x4C4C,
-		LO=0x4C4F,MN=0x4D4E,MT=0x4D54,NN=0x4E4E,PB=0x5042,PE=0x5045,
-		PL=0x504C,PM=0x504D,PN=0x504E,PP=0x5050,PS=0x5053,PT=0x5054,
-		PU=0x5055,PW=0x5057,PX=0x5058,RL=0x524C,RN=0x524E,ST=0x5354,
-		SA=0x5341,SC=0x5343,SD=0x5344,SG=0x5347,SI=0x5349,SO=0x534F,
-		SP=0x5350,SR=0x5352,SL=0x534C,SX=0x5358,SY=0x5359,SZ=0x535A,
-		TA=0x5441,UO=0x554F};
+		LO=0x4C4F,MD=0x4D44,MN=0x4D4E,MT=0x4D54,NN=0x4E4E,PB=0x5042,
+		PD=0x5044,PE=0x5045,PL=0x504C,PM=0x504D,PN=0x504E,PP=0x5050,
+		PS=0x5053,PT=0x5054,PU=0x5055,PW=0x5057,PX=0x5058,RL=0x524C,
+		RN=0x524E,RS=0x5253,RR=0x5252,SA=0x5341,SC=0x5343,SD=0x5344,
+		SG=0x5347,SI=0x5349,SL=0x534C,SN=0x534e,SO=0x534F,SP=0x5350,
+		SR=0x5352,ST=0x5354,SX=0x5358,SY=0x5359,SZ=0x535A,TA=0x5441,
+		UO=0x554F};
   enum Role {Invalid=0,Cmd=1,Reply=2};
   RDMacro();
   RDMacro::Role role() const;
