@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdreport.cpp,v 1.20 2007/09/14 14:06:24 fredg Exp $
+//      $Id: rdreport.cpp,v 1.23.2.2 2009/01/13 19:27:13 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,7 +25,8 @@
 #include <rdcreate_log.h>
 #include <rdlog_line.h>
 #include <rdescape_string.h>
-
+#include <rddb.h>
+#include <rdescape_string.h>
 
 RDReport::RDReport(const QString &rptname,QObject *parent,const char *name)
 {
@@ -42,9 +43,10 @@ QString RDReport::name() const
 
 bool RDReport::exists()
 {
-  QSqlQuery *q=new QSqlQuery(QString().sprintf("select NAME from REPORTS\
+  RDSqlQuery *q=new RDSqlQuery(QString().sprintf("select NAME from REPORTS\
                                                 where NAME=\"%s\"",
-					       (const char *)report_name));
+						 (const char *)
+						 RDEscapeString(report_name)));
   if(!q->first()) {
     delete q;
     return false;
@@ -228,9 +230,9 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
 			      RDStation *station)
 {
   QString sql;
-  QSqlQuery *q;
-  QSqlQuery *q1;
-  QSqlQuery *q2;
+  RDSqlQuery *q;
+  RDSqlQuery *q1;
+  RDSqlQuery *q2;
   RDSvc *svc;
   QString rec_name;
   QString station_sql;
@@ -246,7 +248,7 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
   sql=QString().sprintf("select STATION_NAME from REPORT_STATIONS \
                          where REPORT_NAME=\"%s\"",
 			(const char *)name());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     station_sql+=QString().sprintf("(STATION_NAME=\"%s\")||",
 				   (const char *)q->value(0).toString());
@@ -270,7 +272,7 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
     }
   }
   sql=sql.left(sql.length()-2);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     group_sql+=QString().sprintf("(CART.GROUP_NAME=\"%s\")||",
 				 (const char *)q->value(0).toString());
@@ -288,15 +290,16 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
     QString().sprintf("MIXDOWN%s",(const char *)station->name());
   mixname=RDEscapeStringSQLColumn(mixname);
   sql=QString().sprintf("drop table `%s_SRT`",(const char *)mixname);
-  q=new QSqlQuery(sql);
-  delete q;
+  QSqlQuery *p;
+  p=new QSqlQuery(sql);
+  delete p;
   sql=RDCreateReconciliationTableSql(mixname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
   sql=QString().sprintf("select SERVICE_NAME from REPORT_SERVICES \
                          where REPORT_NAME=\"%s\"",
 			(const char *)name());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     svc=new RDSvc(q->value(0).toString());
     if(svc->exists()) {
@@ -352,7 +355,7 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
       sql=sql.left(sql.length()-2);
       sql+=")";
 
-      q1=new QSqlQuery(sql);
+      q1=new RDSqlQuery(sql);
       while(q1->next()) {
 	sql=QString().sprintf("insert into `%s_SRT` set\
                              LENGTH=%d,LOG_ID=%u,CART_NUMBER=%d,\
@@ -377,30 +380,44 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
 			      q1->value(0).toInt(),
 			      q1->value(1).toUInt(),
 			      q1->value(2).toInt(),
-			      (const char *)q1->value(3).toString(),
-			      (const char *)q1->value(4).toString(),
+			      (const char *)
+			      RDEscapeString(q1->value(3).toString()),
+			      (const char *)
+			      RDEscapeString(q1->value(4).toString()),
 			      q1->value(5).toInt(),
-			      (const char *)q1->value(6).toString(),
+			      (const char *)
+			      RDEscapeString(q1->value(6).toString()),
 			      q1->value(7).toInt(),
-			      (const char *)q1->value(8).toString(),
-			      (const char *)q1->value(9).toString(),
-			      (const char *)q1->value(10).toString(),
+			      (const char *)
+			      RDEscapeString(q1->value(8).toString()),
+			      (const char *)
+			      RDEscapeString(q1->value(9).toString()),
+			      (const char *)
+			      RDEscapeString(q1->value(10).toString()),
 			      q1->value(11).toInt(),
 			      q1->value(12).toInt(),
 			      q1->value(13).toInt(),
-			      (const char *)q1->value(14).toString(),
-			      (const char *)q1->value(15).toString(),
-			      (const char *)q1->value(16).toString(),
-			      (const char *)q1->value(17).toString(),
+			      (const char *)
+			      RDEscapeString(q1->value(14).toString()),
+			      (const char *)
+			      RDEscapeString(q1->value(15).toString()),
+			      (const char *)
+			      RDEscapeString(q1->value(16).toString()),
+			      (const char *)
+			      RDEscapeString(q1->value(17).toString()),
 			      (const char *)q1->value(18).toDate().
 			      toString("yyyy-MM-dd hh:mm:ss"),
 			      q1->value(19).toInt(),
-			      (const char *)q1->value(20).toString(),
-			      (const char *)q1->value(21).toString(),
-			      (const char *)q1->value(22).toString(),
+			      (const char *)
+			      RDEscapeString(q1->value(20).toString()),
+			      (const char *)
+			      RDEscapeString(q1->value(21).toString()),
+			      (const char *)
+			      RDEscapeString(q1->value(22).toString()),
 			      q1->value(23).toInt(),
-			      (const char *)q1->value(24).toString());
-	q2=new QSqlQuery(sql);
+			      (const char *)
+			      RDEscapeString(q1->value(24).toString()));
+	q2=new RDSqlQuery(sql);
 	delete q2;
       }
       delete q1;
@@ -437,7 +454,7 @@ bool RDReport::generateReport(const QDate &startdate,const QDate &enddate,
   }
   // printf("MIXDOWN TABLE: %s_SRT\n",(const char *)mixname);
   sql=QString().sprintf("drop table `%s_SRT`",(const char *)mixname);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 
   return ret;
@@ -551,57 +568,56 @@ QString RDReport::errorText(RDReport::ErrorCode code)
 
 void RDReport::SetRow(const QString &param,QString value)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
-  value.replace("\\","\\\\");  // Needed to preserve Windows pathnames
   sql=QString().sprintf("UPDATE REPORTS SET %s=\"%s\" WHERE NAME=\"%s\"",
 			(const char *)param,
-			(const char *)value,
+			(const char *)RDEscapeString(value),
 			(const char *)report_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDReport::SetRow(const QString &param,int value)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE REPORTS SET %s=%d WHERE NAME=\"%s\"",
 			(const char *)param,
 			value,
 			(const char *)report_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDReport::SetRow(const QString &param,unsigned value)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE REPORTS SET %s=%u WHERE NAME=\"%s\"",
 			(const char *)param,
 			value,
 			(const char *)report_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDReport::SetRow(const QString &param,bool value)
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE REPORTS SET %s=\"%s\" WHERE NAME=\"%s\"",
 			(const char *)param,
 			(const char *)RDYesNo(value),
 			(const char *)report_name);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
@@ -648,4 +664,3 @@ QString RDReport::TypeFieldName(ExportType type,bool forced)
   }
   return QString();
 }
-
