@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: pie_counter.cpp,v 1.31 2007/09/14 14:06:48 fredg Exp $
+//      $Id: pie_counter.cpp,v 1.34 2008/04/20 19:17:34 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -40,6 +40,7 @@ PieCounter::PieCounter(int count_length,QWidget *parent,const char *name)
   pie_op_mode=RDAirPlayConf::LiveAssist;
   pie_trans_type=RDLogLine::Stop;
   air_line=-1;
+  pie_onair=false;
   const int ring = (PIE_COUNTER_BBOX-PIE_COUNTER_SIZE)/2; 
   QFont font=QFont("Helvetica",30,QFont::Bold);
   font.setPixelSize(30);
@@ -160,6 +161,15 @@ void PieCounter::setLogline(RDLogLine *logline)
 }
 
 
+void PieCounter::setErasePixmap(const QPixmap &pix)
+{
+  pie_pixmap=pix;
+  if(!pie_onair) {
+    QWidget::setErasePixmap(pie_pixmap);
+  }
+}
+
+
 void PieCounter::stop()
 {
   pie_running=false;
@@ -173,12 +183,19 @@ void PieCounter::setOnairFlag(bool state)
 {
   if(state) {
     setBackgroundColor(PIE_ONAIR_COLOR);
+    QWidget::setErasePixmap(QPixmap());
     pie_time_label->setBackgroundColor(PIE_ONAIR_COLOR);
+    pie_talk_label->setBackgroundColor(PIE_ONAIR_COLOR);
   }
   else {
     setBackgroundColor(onair_off_color);
+    if(!pie_pixmap.isNull()) {
+      QWidget::setErasePixmap(pie_pixmap);
+    }
     pie_time_label->setBackgroundColor(onair_off_color);
+    pie_talk_label->setBackgroundColor(onair_off_color);
   }
+  pie_onair=state;
 }
 
 
@@ -237,8 +254,13 @@ void PieCounter::paintEvent(QPaintEvent *e)
   if (pie_time > pie_count_length) 
 	  ring_angle = 0;
 
-  if((!pie_running)||(pie_length==0)||(angle>5760)) {
+  if(pie_onair||pie_pixmap.isNull()) {
     p->fillRect(0,0,PIE_COUNTER_BBOX,PIE_COUNTER_BBOX,backgroundColor());
+  }
+  else {
+    p->drawPixmap(-PIE_X_PADDING,-PIE_Y_PADDING,pie_pixmap);
+  }
+  if((!pie_running)||(pie_length==0)||(angle>5760)) {
     p->setBrush (PIE_FINAL_BG_COLOR);
     p->setPen(PIE_FINAL_BG_COLOR);
     p->drawPie(0,0,PIE_COUNTER_BBOX,PIE_COUNTER_BBOX,0,5759);
@@ -248,7 +270,6 @@ void PieCounter::paintEvent(QPaintEvent *e)
   }
   else { 
     // Clear the pixmap 	  
-    p->fillRect(0,0,PIE_COUNTER_BBOX,PIE_COUNTER_BBOX,backgroundColor());
     // This is the outer ring 
     p->setBrush (PIE_FINAL_BG_COLOR);
     p->setPen(PIE_FINAL_BG_COLOR);
@@ -304,7 +325,6 @@ void PieCounter::SetPieColor()
 	switch(pie_trans_type) {
 	    case RDLogLine::Play:
 	    case RDLogLine::Segue:
-	    case RDLogLine::Overlap:
 	      pie_color=BUTTON_STOPPED_BACKGROUND_COLOR;
 	      break;
 	      
