@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: list_casts.h,v 1.5 2007-11-29 19:29:19 fredg Exp $
+//      $Id: list_casts.h,v 1.6 2008/09/18 19:02:14 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -61,6 +61,7 @@ class ListCasts : public QDialog
   QString GetExportCommand(const QString &srcfile,QString *destfile);
   QString GetImportCommand(const QString &srcfile,QString *destfile);
   QString GetTempFilename();
+  void GetEncoderId();
   RDListView *list_casts_view;
   QPushButton *list_cart_button;
   QPushButton *list_file_button;
@@ -72,6 +73,7 @@ class ListCasts : public QDialog
   QPixmap *list_greenball_map;
   QPixmap *list_whiteball_map;
   unsigned list_feed_id;
+  int list_encoder_id;
 };
 
 
