@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: disk_ripper.h,v 1.4 2007/02/14 21:55:07 fredg Exp $
+//      $Id: disk_ripper.h,v 1.5 2007/09/14 14:06:55 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -37,10 +37,11 @@
 #include <qcombobox.h>
 #include <qcheckbox.h>
 #include <qtextedit.h>
-#include <rtransportbutton.h>
-#include <rcdplayer.h>
-#include <rcddbrecord.h>
-#include <rcddblookup.h>
+
+#include <rdtransportbutton.h>
+#include <rdcdplayer.h>
+#include <rdcddbrecord.h>
+#include <rdcddblookup.h>
 
 #include <rdlibrary_conf.h>
 #include <rd.h>
@@ -67,7 +68,7 @@ class DiskRipper : public QDialog
   void mediaChangedData();
   void playedData(int);
   void stoppedData();
-  void cddbDoneData(RCddbLookup::Result);
+  void cddbDoneData(RDCddbLookup::Result);
   void normalizeCheckData(bool);
   void autotrimCheckData(bool);
   void barTimerData();
@@ -82,9 +83,9 @@ class DiskRipper : public QDialog
   void RipTrack(int track,QString cutname,QString title);
   int GetTotalLength();
   void AutoTrim();
-  RCdPlayer *rip_cdrom;
-  RCddbRecord rip_cddb_record;
-  RCddbLookup *rip_cddb_lookup;
+  RDCdPlayer *rip_cdrom;
+  RDCddbRecord rip_cddb_record;
+  RDCddbLookup *rip_cddb_lookup;
   QListView *rip_track_list;
   QPushButton *rip_rip_button;
   bool rip_rip_aborted;
@@ -94,9 +95,9 @@ class DiskRipper : public QDialog
   QTextEdit *rip_other_edit;
   QCheckBox *rip_apply_box;
   QLabel *rip_apply_label;
-  RTransportButton *rip_eject_button;
-  RTransportButton *rip_play_button;
-  RTransportButton *rip_stop_button;
+  RDTransportButton *rip_eject_button;
+  RDTransportButton *rip_play_button;
+  RDTransportButton *rip_stop_button;
   QPushButton *rip_setall_button;
   QPushButton *rip_setcut_button;
   QString rip_cutname;
