@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlibrary.cpp,v 1.101 2007/09/14 14:06:55 fredg Exp $
+//      $Id: rdlibrary.cpp,v 1.106.2.1 2009/01/09 14:41:40 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -26,9 +26,9 @@
 #include <sys/wait.h>
 
 #include <qapplication.h>
+#include <qeventloop.h>
 #include <qwidget.h>
 #include <qpainter.h>
-#include <qsqldatabase.h>
 #include <qsqlpropertymap.h>
 #include <qmessagebox.h>
 #include <qlabel.h>
@@ -36,21 +36,21 @@
 #include <qtranslator.h>
 #include <qlabel.h>
 #include <qlistview.h>
+#include <qprogressdialog.h>
 
 #include <rd.h>
+#include <rddb.h>
 #include <rdconf.h>
 #include <rduser.h>
 #include <rdripc.h>
 #include <rdmixer.h>
 #include <rdadd_cart.h>
 #include <rdprofile.h>
-#include <rdstation.h>
 #include <rdaudio_port.h>
 #include <rdcart_search_text.h>
 #include <rdcheck_daemons.h>
 #include <rdtextvalidator.h>
 #include <rdcmd_switch.cpp>
-#include <rddbheartbeat.h>
 
 #include <filter.h>
 #include <edit_cart.h>
@@ -90,7 +90,7 @@ void SigHandler(int signo);
 
 
 MainWidget::MainWidget(QWidget *parent,const char *name)
-  :QWidget(parent,name)
+  :QDialog(parent,name)
 {
   //
   // Ensure We're the Only Instance Running
@@ -145,6 +145,21 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   RDTextValidator *validator=new RDTextValidator(this,"validator");
 
+  //
+  // Progress Dialog
+  //
+  lib_progress_dialog=
+    new QProgressDialog(tr("Please Wait..."),"Cancel",10,this,
+			"lib_progress_dialog",false,
+			Qt::WStyle_Customize|Qt::WStyle_NormalBorder);
+  lib_progress_dialog->setCaption(" ");
+  QLabel *label=new QLabel(tr("Please Wait..."),lib_progress_dialog);
+  label->setAlignment(AlignCenter);
+  label->setFont(filter_font);
+  lib_progress_dialog->setLabel(label);
+  lib_progress_dialog->setCancelButton(NULL);
+  lib_progress_dialog->setMinimumDuration(2000);
+
   //
   // Ensure that the system daemons are running
   //
@@ -168,30 +183,20 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   //
   // Open Database
   //
-  lib_db=QSqlDatabase::addDatabase(lib_config->mysqlDriver());
-  if(!lib_db) {
+  QString err (tr("rdlibrary : "));
+  QSqlDatabase *db=RDInitDb (&err);
+  if(!db) {
     QMessageBox::warning(this,
-			 tr("Can't Connect"),
-			 tr("Unable to connect to mySQL Server!"));
+			 tr("Can't Connect"),err);
     exit(0);
   }
-  lib_db->setDatabaseName(lib_config->mysqlDbname());
-  lib_db->setUserName(lib_config->mysqlUsername());
-  lib_db->setPassword(lib_config->mysqlPassword());
-  lib_db->setHostName(lib_config->mysqlHostname());
-  if(!lib_db->open()) {
-    QMessageBox::warning(this,tr("Can't Connect"),
-			 tr("Unable to connect to mySQL Server!"));
-    lib_db->removeDatabase(lib_config->mysqlDbname());
-    exit(0);
-  }
-  new RDDbHeartbeat(lib_config->mysqlHeartbeatInterval(),this);
 
   //
   // Allocate Global Resources
   //
   rdlibrary_conf=new RDLibraryConf(lib_config->stationName(),0);
   rdstation_conf=new RDStation(lib_config->stationName());
+  lib_filter_mode=rdstation_conf->filterMode();
   rdaudioport_conf=new RDAudioPort(lib_config->stationName(),
 				   rdlibrary_conf->inputCard());
   rdripc=new RDRipc(lib_config->stationName());
@@ -214,6 +219,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Filter
   //
   lib_filter_edit=new QLineEdit(this,"filter_edit");
+  lib_filter_edit->setFont(default_font);
   lib_filter_edit->setValidator(validator);
   lib_filter_label=new QLabel(lib_filter_edit,tr("Filter:"),
 			      this,"filter_label");
@@ -222,6 +228,22 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   connect(lib_filter_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(filterChangedData(const QString &)));
 
+  //
+  // Filter Search Button
+  //
+  lib_search_button=new QPushButton(tr("&Search"),this,"search_button");
+  lib_search_button->setFont(button_font);
+  lib_search_button->setDefault(true);
+  connect(lib_search_button,SIGNAL(clicked()),this,SLOT(searchClickedData()));
+  switch(lib_filter_mode) {
+    case RDStation::FilterSynchronous:
+      lib_search_button->hide();
+      break;
+
+    case RDStation::FilterAsynchronous:
+      break;
+  }
+
   //
   // Filter Clear Button
   //
@@ -234,6 +256,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Group Filter
   //
   lib_group_box=new QComboBox(this,"lib_group_box");
+  lib_group_box->setFont(default_font);
   lib_group_label=new QLabel(lib_group_box,tr("Group:"),
 			     this,"lib_group_label");
   lib_group_label->setFont(button_font);
@@ -245,12 +268,13 @@ MainWidget::MainWidget(QWidget *parent,const char *name)
   // Scheduler Codes Filter
   //
   lib_codes_box=new QComboBox(this,"lib_codes_box");
+  lib_codes_box->setFont(default_font);
   lib_codes_label=new QLabel(lib_codes_box,tr("Scheduler Code:"),
 			     this,"lib_codes_label");
   lib_codes_label->setFont(button_font);
   lib_codes_label->setAlignment(AlignVCenter|AlignRight);
   connect(lib_codes_box,SIGNAL(activated(const QString &)),
-	  this,SLOT(RefreshList()));
+	  this,SLOT(groupActivatedData(const QString &)));
 
   //
   // Show Audio Carts Checkbox
@@ -423,7 +447,7 @@ void MainWidget::connectedData(bool state)
 void MainWidget::userData()
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
 
   SetCaption(rdripc->user());
   if(lib_user!=NULL) {
@@ -436,7 +460,7 @@ void MainWidget::userData()
   sql=QString().sprintf("select GROUP_NAME from USER_PERMS\
                               where USER_NAME=\"%s\" order by GROUP_NAME",
 			     (const char *)lib_user->name());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     lib_group_box->insertItem(q->value(0).toString());
   }
@@ -459,18 +483,30 @@ void MainWidget::userData()
   lib_codes_box->clear();
   lib_codes_box->insertItem(tr(""));
   sql=QString().sprintf("select CODE from SCHED_CODES");
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   while(q->next()) {
     lib_codes_box->insertItem(q->value(0).toString());
   }
   delete q;
   RefreshList();
+  lib_search_button->setDisabled(true);
 }
 
 
 void MainWidget::filterChangedData(const QString &str)
 {
-  if(str.isEmpty()) {
+  lib_search_button->setEnabled(true);
+  if(lib_filter_mode!=RDStation::FilterSynchronous) {
+    return;
+  }
+  searchClickedData();
+}
+
+
+void MainWidget::searchClickedData()
+{
+  lib_search_button->setDisabled(true);
+  if(lib_filter_edit->text().isEmpty()) {
     lib_clear_button->setDisabled(true);
   }
   else {
@@ -492,18 +528,18 @@ void MainWidget::groupActivatedData(const QString &str)
   if(str!=tr("ALL")) {
     lib_default_group=str;
   }
-  RefreshList();
+  filterChangedData("");
 }
 
 
 void MainWidget::addData()
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   int cart_num;
   RDCart::Type cart_type=RDCart::All;
   QString cart_title;
-
+  
   RDAddCart *add_cart=new RDAddCart(&lib_default_group,&cart_type,&cart_title,
 				    lib_user->name(),this,"add_cart");
   if((cart_num=add_cart->exec())<0) {
@@ -516,31 +552,30 @@ void MainWidget::addData()
 			cart_num,cart_type,
 			(const char *)lib_default_group,
 			(const char *)cart_title);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
-
-  EditCart *cart=new EditCart(cart_num,&lib_import_path,true,this);
-   if(cart->exec() <0)
-   {
-      RDCart *rdcart=new RDCart(cart_num);
-      rdcart->remove();
-      delete rdcart;
-   } else {
-
-  RDListViewItem *item=new RDListViewItem(lib_cart_list);
-  item->setText(1,QString().sprintf("%06u",cart_num));
-  RefreshLine(item);
-  QListViewItemIterator it(lib_cart_list);
-  while(it.current()) {
-    lib_cart_list->setSelected(it.current(),false);
-    ++it;
-  }
-  lib_cart_list->setSelected(item,true);
-}
-   delete cart;
- 
- }
   
+  EditCart *cart=new EditCart(cart_num,&lib_import_path,true,this);
+  if(cart->exec() <0) {
+    RDCart *rdcart=new RDCart(cart_num);
+    rdcart->remove();
+    delete rdcart;
+  } 
+  else {
+    RDListViewItem *item=new RDListViewItem(lib_cart_list);
+    item->setText(1,QString().sprintf("%06u",cart_num));
+    RefreshLine(item);
+    QListViewItemIterator it(lib_cart_list);
+    while(it.current()) {
+      lib_cart_list->setSelected(it.current(),false);
+      ++it;
+    }
+    lib_cart_list->setSelected(item,true);
+    lib_cart_list->ensureItemVisible(item);
+  }
+  delete cart;
+}
+
 
 
 void MainWidget::editData()
@@ -601,7 +636,7 @@ void MainWidget::deleteData()
 {
   QString filename;
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString str;
   int sel_count=0;
   QListViewItemIterator *it;
@@ -638,7 +673,7 @@ void MainWidget::deleteData()
   sql=QString().sprintf("select CUT_NAME from RECORDINGS where \
                          (CUT_NAME like \"%06u_%%\")||(MACRO_CART=%u)",
 			item->text(1).toUInt(),item->text(1).toUInt());
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   if(q->first()) {
       QString str=QString().sprintf(tr("Cart %06u is used in one or more RDCatch events!\n\
 Do you still want to delete it?"),item->text(1).toUInt());
@@ -759,20 +794,19 @@ void MainWidget::cartDoubleclickedData(QListViewItem *,const QPoint &,int)
 
 void MainWidget::audioChangedData(int state)
 {
-  RefreshList();
+  filterChangedData("");
 }
 
 
 void MainWidget::macroChangedData(int state)
 {
-  RefreshList();
+  filterChangedData("");
 }
 
 
 void MainWidget::quitMainWidget()
 {
   SaveGeometry();
-  lib_db->removeDatabase(lib_config->mysqlDbname());
   lib_lock->unlock();
   exit(0);
 }
@@ -786,26 +820,35 @@ void MainWidget::closeEvent(QCloseEvent *e)
 
 void MainWidget::resizeEvent(QResizeEvent *e)
 {
-  lib_filter_edit->setGeometry(70,10,e->size().width()-170,20);
+  switch(lib_filter_mode) {
+    case RDStation::FilterSynchronous:
+      lib_filter_edit->setGeometry(70,10,e->size().width()-170,20);
+      break;
+
+    case RDStation::FilterAsynchronous:
+      lib_search_button->setGeometry(e->size().width()-180,10,80,50);
+      lib_filter_edit->setGeometry(70,10,e->size().width()-260,20);
+      break;
+  }
   lib_clear_button->setGeometry(e->size().width()-90,10,80,50);
   lib_filter_label->setGeometry(10,10,55,20);
   lib_group_box->setGeometry(70,40,120,20);
   lib_group_label->setGeometry(10,40,55,20);
   lib_codes_box->setGeometry(300,40,120,20);
   lib_codes_label->setGeometry(195,40,100,20);
-  lib_showaudio_box->setGeometry(450,42,15,15);
-  lib_showaudio_label->setGeometry(470,40,130,20);
-  lib_showmacro_box->setGeometry(590,42,15,15);
-  lib_showmacro_label->setGeometry(610,40,100,20);
+  lib_showaudio_box->setGeometry(70,67,15,15);
+  lib_showaudio_label->setGeometry(90,65,130,20);
+  lib_showmacro_box->setGeometry(230,67,15,15);
+  lib_showmacro_label->setGeometry(250,65,130,20);
   lib_cart_list->
-    setGeometry(10,70,e->size().width()-20,e->size().height()-135);
+    setGeometry(10,90,e->size().width()-20,e->size().height()-155);
   lib_add_button->setGeometry(10,e->size().height()-60,80,50);
   lib_edit_button->setGeometry(100,e->size().height()-60,80,50);
   lib_delete_button->setGeometry(190,e->size().height()-60,80,50);
-  disk_gauge->setGeometry(280,e->size().height()-50,
+  disk_gauge->setGeometry(290,e->size().height()-45,
 			  disk_gauge->sizeHint().width(),
 			  disk_gauge->sizeHint().height());
-  lib_rip_button->setGeometry(230+disk_gauge->sizeHint().width()+
+  lib_rip_button->setGeometry(240+disk_gauge->sizeHint().width()+
 			      (e->size().width()-90-
 			       (280+disk_gauge->sizeHint().width()))/2-45,
 			      e->size().height()-60,80,50);
@@ -820,13 +863,14 @@ void MainWidget::resizeEvent(QResizeEvent *e)
 
 void MainWidget::RefreshList()
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
   RDListViewItem *l=NULL;
   QString type_filter;
   QDateTime current_datetime(QDate::currentDate(),QTime::currentTime());
   unsigned cartnum=0;
   RDCart::Validity validity=RDCart::NeverValid;
+  QDateTime end_datetime;
 
   lib_cart_list->clear();
 
@@ -868,8 +912,13 @@ void MainWidget::RefreshList()
     }  
   
   sql+=" order by CART.NUMBER";
-  q=new QSqlQuery(sql,lib_db);
+  q=new RDSqlQuery(sql);
+  int step=0;
+  int count=0;
+  lib_progress_dialog->setTotalSteps(q->size()/RDLIBRARY_STEP_SIZE);
+  lib_progress_dialog->setProgress(0);
   while(q->next()) {
+    end_datetime=q->value(9).toDateTime();
     if(q->value(0).toUInt()==cartnum) {
       if((RDCart::Type)q->value(10).toUInt()==RDCart::Macro) {
 	validity=RDCart::AlwaysValid;
@@ -882,32 +931,7 @@ void MainWidget::RefreshList()
       //
       // Write availability color
       //
-      if(l!=NULL) {
-	switch(validity) {
-	    case RDCart::NeverValid:
-	      l->setBackgroundColor(RD_CART_ERROR_COLOR);
-	      break;
-	      
-	    case RDCart::ConditionallyValid:
-	      if((!q->value(9).isNull())&&
-		 (q->value(9).toDateTime()<current_datetime)) {
-		l->setBackgroundColor(RD_CART_ERROR_COLOR);
-	      }
-	      else {
-		l->setBackgroundColor(RD_CART_CONDITIONAL_COLOR);
-	      }
-	      break;
-	      
-	    case RDCart::AlwaysValid:
-	      l->setBackgroundColor(palette().color(QPalette::Active,
-						    QColorGroup::Base));
-	      break;
-	      
-	    case RDCart::EvergreenValid:
-	      l->setBackgroundColor(RD_CART_EVERGREEN_COLOR);
-	      break;
-	}
-      }
+      UpdateItemColor(l,validity,q->value(9).toDateTime(),current_datetime);
 
       //
       // Start a new entry
@@ -989,7 +1013,14 @@ void MainWidget::RefreshList()
       }
     }
     cartnum=q->value(0).toUInt();
+    if(count++>RDLIBRARY_STEP_SIZE) {
+      lib_progress_dialog->setProgress(++step);
+      count=0;
+      qApp->eventLoop()->processEvents(QEventLoop::ExcludeUserInput);
+    }
   }
+  UpdateItemColor(l,validity,end_datetime,current_datetime);
+  lib_progress_dialog->reset();
   delete q;
 }
 
@@ -1035,7 +1066,7 @@ void MainWidget::RefreshLine(RDListViewItem *item)
                                  CUTS on CART.NUMBER=CUTS.CART_NUMBER \
                                  where CART.NUMBER=%u",
 				item->text(1).toUInt());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
     if((RDCart::Type)q->value(9).toUInt()==RDCart::Macro) {
       validity=RDCart::AlwaysValid;
@@ -1055,30 +1086,8 @@ void MainWidget::RefreshLine(RDListViewItem *item)
 	    item->setBackgroundColor(RD_CART_ERROR_COLOR);
 	  }
 	  else {
-	    switch((RDCart::Validity)q->value(17).toUInt()) {
-	      case RDCart::NeverValid:
-		item->setBackgroundColor(RD_CART_ERROR_COLOR);
-		break;
-		
-	      case RDCart::ConditionallyValid:
-		if((!q->value(8).isNull())&&
-		   (q->value(8).toDateTime()>current_datetime)) {
-		  item->setBackgroundColor(RD_CART_ERROR_COLOR);
-		}
-		else {
-		  item->setBackgroundColor(RD_CART_CONDITIONAL_COLOR);
-		}
-		break;
-		
-	      case RDCart::AlwaysValid:
-		item->setBackgroundColor(palette().color(QPalette::Active,
-							 QColorGroup::Base));
-		break;
-		
-	      case RDCart::EvergreenValid:
-		item->setBackgroundColor(RD_CART_EVERGREEN_COLOR);
-		break;
-	  }
+	    UpdateItemColor(item,(RDCart::Validity)q->value(17).toUInt(),
+			    q->value(8).toDateTime(),current_datetime);
 	  }
 	  break;
 
@@ -1148,6 +1157,40 @@ void MainWidget::RefreshLine(RDListViewItem *item)
 }
 
 
+void MainWidget::UpdateItemColor(RDListViewItem *item,
+				 RDCart::Validity validity,
+				 const QDateTime &end_datetime,
+				 const QDateTime &current_datetime)
+{
+  if(item!=NULL) {
+    switch(validity) {
+      case RDCart::NeverValid:
+	item->setBackgroundColor(RD_CART_ERROR_COLOR);
+	break;
+	
+      case RDCart::ConditionallyValid:
+	if(end_datetime.isValid()&&
+	   (end_datetime<current_datetime)) {
+	  item->setBackgroundColor(RD_CART_ERROR_COLOR);
+	}
+	else {
+	  item->setBackgroundColor(RD_CART_CONDITIONAL_COLOR);
+	}
+	break;
+	
+      case RDCart::AlwaysValid:
+	item->setBackgroundColor(palette().color(QPalette::Active,
+					      QColorGroup::Base));
+	break;
+	
+      case RDCart::EvergreenValid:
+	item->setBackgroundColor(RD_CART_EVERGREEN_COLOR);
+	break;
+    }
+  }
+}
+
+
 void MainWidget::SetCaption(QString user)
 {
   QString str1;
@@ -1231,15 +1274,20 @@ int main(int argc,char *argv[])
 	  ".");
   a.installTranslator(&qt);
 
-  QTranslator libradio(0);
-  libradio.load(QString(PREFIX)+QString("/share/srlabs/libradio_")+
-		QTextCodec::locale(),".");
-  a.installTranslator(&libradio);
-
-  QTranslator tests(0);
-  tests.load(QString(PREFIX)+QString("/share/srlabs/rdlibrary_")+
+  QTranslator rd(0);
+  rd.load(QString(PREFIX)+QString("/share/rivendell/librd_")+
 	     QTextCodec::locale(),".");
-  a.installTranslator(&tests);
+  a.installTranslator(&rd);
+
+  QTranslator rdhpi(0);
+  rdhpi.load(QString(PREFIX)+QString("/share/rivendell/librdhpi_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&rdhpi);
+
+  QTranslator tr(0);
+  tr.load(QString(PREFIX)+QString("/share/rivendell/rdlibrary_")+
+	     QTextCodec::locale(),".");
+  a.installTranslator(&tr);
 
   //
   // Start Event Loop
