@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2005 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdlogedit.cpp,v 1.65 2008/01/02 12:18:39 fredg Exp $
+//      $Id: rdlogedit.cpp,v 1.68 2008/04/22 19:54:08 grauf Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -218,7 +218,7 @@ MainWidget::MainWidget(QWidget *parent,const char *name,WFlags f)
   RDSetMixerPorts(log_config->stationName(),rdcae);
 
 #else 
-  rduser=new RDUser("user");
+  rduser=new RDUser(RD_USER_LOGIN_NAME);
 #endif  // WIN32
 
   // 
@@ -368,6 +368,9 @@ void MainWidget::userData()
 			       (const char *)log_config->stationName(),
 			       (const char *)str2,
 			       (const char *)rdripc->user()));
+  if(rduser!=NULL) {
+    delete rduser;
+  }
   rduser=new RDUser(rdripc->user());
 
   //
@@ -377,6 +380,11 @@ void MainWidget::userData()
   log_delete_button->setEnabled(rduser->deleteLog());
 //  log_track_allowed=rduser->voicetrackLog();
   log_track_button->setEnabled(rduser->voicetrackLog());
+
+  // Update the list of logs if applicable.
+  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
+    RefreshList();
+  }
 }
 
 
@@ -387,10 +395,15 @@ void MainWidget::addData()
   RDSqlQuery *q;
   QString sql;
   std::vector<QString> newlogs;
+  RDAddLog *log;
 
   if(rduser->createLog()) {
-    RDAddLog *log=
-      new RDAddLog(&logname,&svcname,NULL,tr("Add Log"),this,"add_log");
+    if (rdstation_conf->broadcastSecurity() == RDStation::UserSec) {
+      log=new RDAddLog(&logname,&svcname,NULL,tr("Add Log"),this,"add_log",
+                       rduser);
+    } else { // RDStation::HostSec
+      log=new RDAddLog(&logname,&svcname,NULL,tr("Add Log"),this,"add_log");
+    }
     if(log->exec()!=0) {
       delete log;
       return;
@@ -734,8 +747,32 @@ void MainWidget::RefreshList()
   QString sql;
   ListListViewItem *item;
 
-  log_log_list->clear();
+  log_log_list->clear(); // Note: clear here, in case user has no perms.
+
   sql="select NAME from LOGS where (TYPE=0)&&(LOG_EXISTS=\"Y\")";
+
+  if (rdstation_conf->broadcastSecurity() == RDStation::UserSec
+      && rduser != NULL) {
+    QStringList services_list;
+    QString sql_where;
+
+    services_list = rduser->services();
+    if(services_list.size()==0) {
+      return;
+    }
+
+    sql_where=" and (";
+    for ( QStringList::Iterator it = services_list.begin(); 
+          it != services_list.end(); ++it ) {
+      sql_where+=QString().sprintf("SERVICE=\"%s\"||",
+                             (const char *)*it);
+    }
+    sql_where=sql_where.left(sql_where.length()-2);
+    sql_where+=")";
+
+    sql=sql+sql_where;
+  } // else no filter for RDStation::HostSec
+
   q=new RDSqlQuery(sql);
   while(q->next()) {
     item=new ListListViewItem(log_log_list);
@@ -763,16 +800,24 @@ int main(int argc,char *argv[])
 			    readEntry("/Rivendell/InstallDir"));
   qt_path=tr_path;
 #else
-  tr_path=QString(PREFIX)+QString("/share/srlabs/");
+  tr_path=QString(PREFIX)+QString("/share/rivendell/");
   qt_path=QString(QTDIR)+QString("/translation/");
 #endif  // WIN32
   QTranslator qt(0);
   qt.load(qt_path+QString("qt_")+QTextCodec::locale(),".");
   a.installTranslator(&qt);
 
-  QTranslator tests(0);
-  tests.load(tr_path+QString("rdlogedit_")+QTextCodec::locale(),".");
-  a.installTranslator(&tests);
+  QTranslator rd(0);
+  rd.load(tr_path+QString("librd_")+QTextCodec::locale(),".");
+  a.installTranslator(&rd);
+
+  QTranslator rdhpi(0);
+  rdhpi.load(tr_path+QString("librdhpi_")+QTextCodec::locale(),".");
+  a.installTranslator(&rdhpi);
+
+  QTranslator tr(0);
+  tr.load(tr_path+QString("rdlogedit_")+QTextCodec::locale(),".");
+  a.installTranslator(&tr);
 
   //
   // Start Event Loop
