@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: livewire.cpp,v 1.1 2007/10/23 18:21:58 fredg Exp $
+//      $Id: livewire.cpp,v 1.4 2008/10/01 13:10:15 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -38,6 +38,16 @@ LiveWire::LiveWire(RDMatrix *matrix,QObject *parent,const char *name)
   livewire_stationname=rdstation->name();
   livewire_matrix=matrix->matrix();
 
+  //
+  // Interval Oneshots
+  //
+  livewire_gpi_oneshot=new RDOneShot(this);
+  connect(livewire_gpi_oneshot,SIGNAL(timeout(void *)),
+	  this,SLOT(gpiOneshotData(void *)));
+  livewire_gpo_oneshot=new RDOneShot(this);
+  connect(livewire_gpo_oneshot,SIGNAL(timeout(void *)),
+	  this,SLOT(gpoOneshotData(void *)));
+  
   //
   // Load The Node List
   //
@@ -67,7 +77,7 @@ LiveWire::LiveWire(RDMatrix *matrix,QObject *parent,const char *name)
 	    this,
 	    SLOT(gpiChangedData(unsigned,unsigned,unsigned,bool)));
     connect(livewire_nodes.back(),
-	    SIGNAL(gp0Changed(unsigned,unsigned,unsigned,bool)),
+	    SIGNAL(gpoChanged(unsigned,unsigned,unsigned,bool)),
 	    this,
 	    SLOT(gpoChangedData(unsigned,unsigned,unsigned,bool)));
     connect(livewire_nodes.back(),
@@ -138,39 +148,88 @@ void LiveWire::processCommand(RDMacro *cmd)
 	break;
 
       case RDMacro::GO:
-	line=cmd->arg(1).toUInt();
+	if((cmd->argQuantity()!=5)||
+	   ((cmd->arg(1).toString().lower()!="i")&&
+	    (cmd->arg(1).toString().lower()!="o"))) {
+	  cmd->acknowledge(false);
+	  emit rmlEcho(cmd);
+	  return;
+	}
+
+	line=cmd->arg(2).toUInt();
 	if(line>RD_LIVEWIRE_MAX_SOURCE) {
 	  cmd->acknowledge(false);
 	  emit rmlEcho(cmd);
 	  return;
 	}
 
-	//
-	// Find the destination node
-	//
-	for(unsigned i=0;i<livewire_nodes.size();i++) {
-	  node=livewire_nodes[i];
-	  for(int j=0;j<node->gpos();j++) {
-	    for(int k=0;k<RD_LIVEWIRE_GPIO_BUNDLE_SIZE;k++) {
-	      if(node->gpoChannel(j,k)==line) {
-		dest_node=node;
-		dest_slot=j;
-		dest_line=k;
+	if(cmd->arg(1).toString().lower()=="i") {
+	  //
+	  // Find the destination node
+	  //
+	  for(unsigned i=0;i<livewire_nodes.size();i++) {
+	    node=livewire_nodes[i];
+	    for(int j=0;j<node->gpos();j++) {
+	      for(int k=0;k<RD_LIVEWIRE_GPIO_BUNDLE_SIZE;k++) {
+		if(node->gpiChannel(j,k)==line) {
+		  dest_node=node;
+		  dest_slot=j;
+		  dest_line=k;
+		}
 	      }
 	    }
 	  }
+	  if(dest_node==NULL) {  // No such GPI!
+	    cmd->acknowledge(false);
+	    emit rmlEcho(cmd);
+	    return;
+	  }
+	  
+	  if(cmd->arg(3).toInt()==0) {  // GPI Off
+	    dest_node->gpiReset(dest_slot,dest_line,cmd->arg(4).toUInt());
+	    emit gpiChanged(livewire_matrix,line-1,false);
+	  }
+	  else {
+	    dest_node->gpiSet(dest_slot,dest_line,cmd->arg(4).toUInt());
+	    if(cmd->arg(4).toUInt()>0) {
+	      livewire_gpi_oneshot->start((void *)(line-1),500);
+	    }
+	    emit gpiChanged(livewire_matrix,line-1,true);
+	  }
 	}
-	if(dest_node==NULL) {  // No such GPO!
-	  cmd->acknowledge(false);
-	  emit rmlEcho(cmd);
-	  return;
-	}
-	
-	if(cmd->arg(2).toInt()==0) {  // GPO Off
-	  dest_node->gpoReset(dest_slot,dest_line,cmd->arg(3).toUInt());
-	}
-	else {
-	  dest_node->gpoSet(dest_slot,dest_line,cmd->arg(3).toUInt());
+	if(cmd->arg(1).toString().lower()=="o") {
+	  //
+	  // Find the destination node
+	  //
+	  for(unsigned i=0;i<livewire_nodes.size();i++) {
+	    node=livewire_nodes[i];
+	    for(int j=0;j<node->gpos();j++) {
+	      for(int k=0;k<RD_LIVEWIRE_GPIO_BUNDLE_SIZE;k++) {
+		if(node->gpoChannel(j,k)==line) {
+		  dest_node=node;
+		  dest_slot=j;
+		  dest_line=k;
+		}
+	      }
+	    }
+	  }
+	  if(dest_node==NULL) {  // No such GPO!
+	    cmd->acknowledge(false);
+	    emit rmlEcho(cmd);
+	    return;
+	  }
+	  
+	  if(cmd->arg(3).toInt()==0) {  // GPO Off
+	    dest_node->gpoReset(dest_slot,dest_line,cmd->arg(4).toUInt());
+	    emit gpoChanged(livewire_matrix,line-1,false);
+	  }
+	  else {
+	    dest_node->gpoSet(dest_slot,dest_line,cmd->arg(4).toUInt());
+	    if(cmd->arg(4).toUInt()>0) {
+	      livewire_gpo_oneshot->start((void *)(line-1),500);
+	    }
+	    emit gpoChanged(livewire_matrix,line-1,true);
+	  }
 	}
 	cmd->acknowledge(true);
 	emit rmlEcho(cmd);
@@ -197,9 +256,22 @@ void LiveWire::sendGpi()
 }
 
 
+void LiveWire::sendGpo()
+{
+  for(unsigned i=0;i<livewire_nodes.size();i++) {
+    for(int j=0;j<livewire_nodes[i]->gpos();j++) {
+      for(int k=0;k<RD_LIVEWIRE_GPIO_BUNDLE_SIZE;k++) {
+	emit gpoState(livewire_matrix,livewire_nodes[i]->gpoChannel(j,k)-1,
+		      livewire_nodes[i]->gpoState(j,k));
+      }
+    }
+  }
+}
+
+
 void LiveWire::nodeConnectedData(unsigned id)
 {
-  LogLine(QString().
+  LogLine(RDConfig::LogInfo,QString().
 	  sprintf("connection established to LiveWire node at \"%s\"",
 		  (const char *)livewire_nodes[id]->hostname()));
 }
@@ -287,33 +359,12 @@ void LiveWire::destinationChangedData(unsigned id,RDLiveWireDestination *dst)
 
 void LiveWire::gpoConfigChangedData(unsigned id,unsigned slot,unsigned chan)
 {
-  QString sql;
-  RDSqlQuery *q;
-
   //
   // FIXME: This creates entries fine, but how can we delete stale ones
   //        without trashing user configs?
   //
-  sql=QString().sprintf("select ID from GPIS where \
-                         (STATION_NAME=\"%s\")&&\
-                         (MATRIX=%d)&&\
-                         (NUMBER=%d)",
-			(const char *)livewire_stationname,
-			livewire_matrix,
-			chan);
-  q=new RDSqlQuery(sql);
-  if(!q->first()) {
-    delete q;
-    sql=QString().sprintf("insert into GPIS set \
-                           STATION_NAME=\"%s\",\
-                           MATRIX=%d,\
-                           NUMBER=%d",
-			  (const char *)livewire_stationname,
-			  livewire_matrix,
-			  chan);
-    q=new RDSqlQuery(sql);
-  }
-  delete q;
+  CreateGpioEntry("GPIS",chan);
+  CreateGpioEntry("GPOS",chan);
 }
 
 
@@ -328,10 +379,55 @@ void LiveWire::gpiChangedData(unsigned id,unsigned slot,unsigned line,
 void LiveWire::gpoChangedData(unsigned id,unsigned slot,unsigned line,
 			      bool state)
 {
+  // printf("gpoChanged(%d,%d,%d)\n",livewire_matrix,livewire_nodes[id]->gpoChannel(slot,line)-1,state);
+  emit gpoChanged(livewire_matrix,livewire_nodes[id]->gpoChannel(slot,line)-1,
+		  state);
 }
 
 
 void LiveWire::watchdogStateChangedData(unsigned id,const QString &msg)
 {
-  LogLine(msg);
+  LogLine(RDConfig::LogNotice,msg);
+}
+
+
+void LiveWire::gpiOneshotData(void *data)
+{
+  emit gpiChanged(livewire_matrix,(long)data,false);
+}
+
+
+void LiveWire::gpoOneshotData(void *data)
+{
+  emit gpoChanged(livewire_matrix,(long)data,false);
+}
+
+
+void LiveWire::CreateGpioEntry(const QString &tablename,int chan)
+{
+  QString sql;
+  RDSqlQuery *q;
+
+  sql=QString().sprintf("select ID from %s where \
+                         (STATION_NAME=\"%s\")&&\
+                         (MATRIX=%d)&&\
+                         (NUMBER=%d)",
+			(const char *)tablename,
+			(const char *)livewire_stationname,
+			livewire_matrix,
+			chan);
+  q=new RDSqlQuery(sql);
+  if(!q->first()) {
+    delete q;
+    sql=QString().sprintf("insert into %s set \
+                           STATION_NAME=\"%s\",\
+                           MATRIX=%d,\
+                           NUMBER=%d",
+			  (const char *)tablename,
+			  (const char *)livewire_stationname,
+			  livewire_matrix,
+			  chan);
+    q=new RDSqlQuery(sql);
+  }
+  delete q;
 }
