@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: local_macros.cpp,v 1.49.2.1 2008-11-07 13:31:18 fredg Exp $
+//      $Id: local_macros.cpp,v 1.49.2.4 2008/12/11 20:13:09 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -44,13 +44,9 @@ void MainObject::gpiChangedData(int matrix,int line,bool state)
   if(!ripcd_gpi_mask[matrix][line]) {
     return;
   }
-  if(state==ripcd_gpi_polarity[matrix][line]) {
-    return;
+  if(ripcd_gpi_macro[matrix][line][state]>0) {
+    ExecCart(ripcd_gpi_macro[matrix][line][state]);
   }
-  if(ripcd_gpi_macro[matrix][line]<=0) {
-    return;
-  }
-  ExecCart(ripcd_gpi_macro[matrix][line]);
 }
 
 
@@ -68,13 +64,9 @@ void MainObject::gpoChangedData(int matrix,int line,bool state)
   if(!ripcd_gpo_mask[matrix][line]) {
     return;
   }
-  if(state==ripcd_gpo_polarity[matrix][line]) {
-    return;
+  if(ripcd_gpo_macro[matrix][line][state]>0) {
+    ExecCart(ripcd_gpo_macro[matrix][line][state]);
   }
-  if(ripcd_gpo_macro[matrix][line]<=0) {
-    return;
-  }
-  ExecCart(ripcd_gpo_macro[matrix][line]);
 }
 
 
@@ -597,27 +589,19 @@ void MainObject::RunLocalMacros(RDMacro *rml)
       }
       switch(gpio_type) {
 	case RDMatrix::GpioInput:
-	  ripcd_gpi_macro[matrix_num][gpi]=rml->arg(4).toInt();
-	  if(rml->arg(2).toInt()==1) {
-	    ripcd_gpi_polarity[matrix_num][gpi]=false;
-	  }
-	  else {
-	    ripcd_gpi_polarity[matrix_num][gpi]=true;
-	  }
-	  BroadcastCommand(QString().sprintf("GC %d %d %d!",matrix_num,gpi,
-					     ripcd_gpi_macro[matrix_num][gpi]));
+	  ripcd_gpi_macro[matrix_num][gpi][rml->arg(3).toInt()]=
+	    rml->arg(4).toInt();
+	  BroadcastCommand(QString().sprintf("GC %d %d %d %d!",matrix_num,gpi,
+				    ripcd_gpi_macro[matrix_num][gpi][0],
+				    ripcd_gpi_macro[matrix_num][gpi][1]));
 	  break;
 
 	case RDMatrix::GpioOutput:
-	  ripcd_gpo_macro[matrix_num][gpi]=rml->arg(4).toInt();
-	  if(rml->arg(2).toInt()==1) {
-	    ripcd_gpo_polarity[matrix_num][gpi]=false;
-	  }
-	  else {
-	    ripcd_gpo_polarity[matrix_num][gpi]=true;
-	  }
-	  BroadcastCommand(QString().sprintf("GD %d %d %d!",matrix_num,gpi,
-					     ripcd_gpo_macro[matrix_num][gpi]));
+	  ripcd_gpo_macro[matrix_num][gpi][rml->arg(3).toInt()]=
+	    rml->arg(4).toInt();
+	  BroadcastCommand(QString().sprintf("GD %d %d %d %d!",matrix_num,gpi,
+				    ripcd_gpo_macro[matrix_num][gpi][0],
+				    ripcd_gpo_macro[matrix_num][gpi][1]));
 	  break;
       }
       if(rml->echoRequested()) {
@@ -1617,6 +1601,10 @@ void MainObject::ForwardConvert(RDMacro *rml) const
       break;
 
     case RDMacro::GI:
+      if(rml->argQuantity()==3) {
+	rml->setArgQuantity(4);
+	rml->setArg(3,0);
+      }
       if(rml->argQuantity()==4) {
 	rml->setArgQuantity(5);
 	for(int i=3;i>=1;i--) {
