@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: sasusi.h,v 1.6 2007/02/14 21:57:04 fredg Exp $
+//      $Id: sasusi.h,v 1.8 2008/09/30 18:19:45 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -42,10 +42,10 @@ class SasUsi : public QObject
  public:
   SasUsi(RDMatrix *matrix,QObject *parent=0,const char *name=0);
   void processCommand(RDMacro *cmd);
-  void processStatus(char *buf,int size);
 
  signals:
   void rmlEcho(RDMacro *cmd);
+  void gpoChanged(int matrix,int line,bool state);
 
  private slots:
   void ipConnect();
@@ -57,7 +57,7 @@ class SasUsi : public QObject
  private:
   void SendCommand(char *str);
   void DispatchCommand();
-  RTTYDevice *sas_device;
+  RDTTYDevice *sas_device;
   QSocket *sas_socket;
   char sas_buffer[SASUSI_MAX_LENGTH];
   unsigned sas_ptr;
